@@ -27,6 +27,7 @@ import warnings
 import traceback
 import locale  # for multilanguage support
 import gettext
+import gc
 from urllib.request import url2pathname
 
 sharedir = os.path.join(sys.prefix, 'share')
@@ -64,7 +65,7 @@ else:
         pass
 
 APPNAME = 'PDF Arranger'
-VERSION = '1.5.1'
+VERSION = '1.5.3'
 WEBSITE = 'https://github.com/jeromerobert/pdfarranger'
 LICENSE = 'GNU General Public License (GPL) Version 3.'
 
@@ -456,6 +457,7 @@ class PdfArranger(Gtk.Application):
 
         self.model.connect('row-inserted', self.__update_num_pages)
         self.model.connect('row-deleted', self.__update_num_pages)
+        self.model.connect('row-deleted', self.reset_export_file)
 
         # Progress bar
         self.progress_bar = self.uiXML.get_object('progressbar')
@@ -531,22 +533,32 @@ class PdfArranger(Gtk.Application):
         self.progress_bar_timeout_id = \
             GObject.timeout_add(50, self.progress_bar_timeout)
 
+    def set_export_file(self, file):
+        if file != self.export_file:
+            self.export_file = file
+            self.set_unsaved(True)
+
     def set_unsaved(self, flag):
         self.is_unsaved = flag
         GObject.idle_add(self.retitle)
 
     def retitle(self):
-        all_files = self.active_file_names()
-        title = ''
-        if len(all_files) == 1:
-            title += all_files.pop()
-        elif len(all_files) == 0:
-            title += _("No document")
+        if self.export_file:
+            title = self.export_file
+            if self.is_unsaved:
+                title += '*'
         else:
-            title += _("Several documents")
-        if self.is_unsaved:
-            title += '*'
-        title += ' - ' + APPNAME
+            title = ''
+
+        all_files = self.active_file_names()
+        if len(all_files) > 0:
+            if title:
+                title += ' '
+            title += '[' + ', '.join(all_files) + ']'
+
+        if title:
+            title += ' – '
+        title += APPNAME
         self.window.set_title(title)
         return False
 
@@ -560,7 +572,7 @@ class PdfArranger(Gtk.Application):
         fraction = 1 if cnt_all == 0 else cnt_finished / cnt_all
 
         self.progress_bar.set_fraction(fraction)
-        self.progress_bar.set_text(_('Rendering thumbnails... [%(i1)s/%(i2)s]')
+        self.progress_bar.set_text(_('Rendering thumbnails… [%(i1)s/%(i2)s]')
                                    % {'i1': cnt_finished, 'i2': cnt_all})
         if fraction >= 0.999:
             self.progress_bar.hide()
@@ -639,6 +651,7 @@ class PdfArranger(Gtk.Application):
 
         # Release Poppler.Document instances to unlock all temporay files
         self.pdfqueue = []
+        gc.collect()
         self.config.set_window_size(self.window.get_size())
         self.config.set_maximized(self.window.is_maximized())
         self.config.set_zoom_level(self.zoom_level)
@@ -650,7 +663,7 @@ class PdfArranger(Gtk.Application):
     def choose_export_pdf_name(self, only_selected=False):
         """Handles choosing a name for exporting """
 
-        chooser = Gtk.FileChooserDialog(title=_('Export ...'),
+        chooser = Gtk.FileChooserDialog(title=_('Export…'),
                                         parent=self.window,
                                         action=Gtk.FileChooserAction.SAVE,
                                         buttons=(Gtk.STOCK_CANCEL,
@@ -672,19 +685,16 @@ class PdfArranger(Gtk.Application):
         filter_all.add_pattern('*')
         chooser.add_filter(filter_all)
 
-        while True:
-            response = chooser.run()
-            if response == Gtk.ResponseType.ACCEPT:
-                file_out = chooser.get_filename()
-                try:
-                    self.save(only_selected, file_out)
-                except Exception as e:
-                    traceback.print_exc()
-                    chooser.destroy()
-                    self.error_message_dialog(e)
-                    return
-            break
+        response = chooser.run()
+        file_out = chooser.get_filename()
         chooser.destroy()
+        if response == Gtk.ResponseType.ACCEPT:
+            try:
+                self.save(only_selected, file_out)
+            except Exception as e:
+                traceback.print_exc()
+                self.error_message_dialog(e)
+                return
 
     def active_file_names(self):
         """Returns the file names currently associated with pages in the model."""
@@ -692,7 +702,8 @@ class PdfArranger(Gtk.Application):
         for row in self.model:
             nfile = row[2]
             f = self.pdfqueue[nfile - 1]
-            all_files.add(f.filename)
+            f = os.path.splitext(os.path.basename(f.filename))[0]
+            all_files.add(f)
         return all_files
 
     def on_action_save(self, _action, _param, _unknown):
@@ -720,17 +731,18 @@ class PdfArranger(Gtk.Application):
             to_export = [row for row in self.model if row.path in selection]
         else:
             self.export_directory = path
-            self.export_file = file_out
-            self.set_unsaved(False)
+            self.set_export_file(file_out)
         m = metadata.merge(self.metadata, self.pdfqueue)
         exporter.export(self.pdfqueue, to_export, file_out, m)
+        if not only_selected:
+            self.set_unsaved(False)
 
     def choose_export_selection_pdf_name(self, _action, _target, _unknown):
         self.choose_export_pdf_name(True)
 
     def on_action_add_doc_activate(self, _action, _param, _unknown):
         """Import doc"""
-        chooser = Gtk.FileChooserDialog(title=_('Import...'),
+        chooser = Gtk.FileChooserDialog(title=_('Import…'),
                                         parent=self.window,
                                         action=Gtk.FileChooserAction.OPEN,
                                         buttons=(Gtk.STOCK_CANCEL,
@@ -1424,6 +1436,11 @@ class PdfArranger(Gtk.Application):
         about_dialog.connect('delete_event', lambda w, *args: w.destroy())
         about_dialog.show_all()
 
+    def reset_export_file(self, model, _path, _itr=None, _user_data=None):
+        if len(model) == 0:
+            self.set_export_file(None)
+            self.set_unsaved(False)
+
     def __update_num_pages(self, model, _path, _itr=None, _user_data=None):
         self.uiXML.get_object("num_pages").set_text(str(len(model)))
 
